==> ct-hayek-1.0.tar.gz: ct-hayek-1.0/main.m <==
// **********************************
// from basic code to apps: changing lines are delimited with
//                                             // +++++++ start
//                                             // +++++++ end
//
// **********************************


// Pietro Terna, Universit di Torino, Dipartimento di Scienze economiche
// e finanziarie, corso Unione Sovietica 218bis, 10134 Torino, Italy
// terna@econ.unito.it
                          
// this code requires Swarm 1.3.1 or 1.4.1 or 2.0.1
// (to use 1,3,1 or 1.4.1 versions you have to modify the lines
//  with the comment '// 1.3.1 or 1.4.1' and '// 2.0.1'
//  in DataWarehouse.m and Agent.m)

// ct-bp project starting date:     August 1998
// this version:                    August 1999

// application name:          ct-hayek
// application starting date: February 1999
// this version:              November 1999


#import <simtools.h>        
#import "ObserverSwarm.h"

int main (int argc, const char **argv)
{
  ObserverSwarm *observerSwarm;

// +++++++ start 
  initSwarmApp (argc, argv,"ct-hayek 1.0 [using bp-ct 1.0]",
                           "terna@econ.unito.it");
// +++++++ end

// Below we have the standard main sequence of any Swarm model:
// 1. creation of the observer; 2. objects creation (one is the Swarm model
// we are dealing with, see ObserverSwarm.m); 3. schedule creation;
// 4. activation of 2. and 3.; 5. go

  observerSwarm =  [ObserverSwarm create: globalZone];

  [observerSwarm buildObjects];
  [observerSwarm buildActions];
  [observerSwarm activateIn: nil];
  
  [observerSwarm go];

  return 0;

}

==> ct-hayek-1.1.tar.gz: ct-hayek-1.1/main.m <==
// **********************************
// from basic code to apps: changing lines are delimited with
//                                             // +++++++ start
//                                             // +++++++ end
//
// **********************************


// Pietro Terna, Universit di Torino, Dipartimento di Scienze economiche
// e finanziarie, corso Unione Sovietica 218bis, 10134 Torino, Italy
// pietro.terna@unito.it
                          
// this code requires Swarm 1.3.1 or 1.4.1 or 2.0.1 or 2.1.1
// (to use 1,3,1 or 1.4.1 versions you have to modify the lines
//  with the comment '// 1.3.1 or 1.4.1' and '// 2.0.1'
//  in DataWarehouse.m and Agent.m)

// ct-bp project starting date:     August 1998
// this version:                    August 2000

// application name:          ct-hayek
// application starting date: February 1999
// this version:              August   2000


#import <simtools.h>        
#import "ObserverSwarm.h"

int main (int argc, const char **argv)
{
  ObserverSwarm *observerSwarm;

// +++++++ start 
  initSwarmApp (argc, argv,"1.1 [using bp-ct 1.1]",
                           "pietro.terna@unito.it");
// +++++++ end

// Below we have the standard main sequence of any Swarm model:
// 1. creation of the observer; 2. objects creation (one is the Swarm model
// we are dealing with, see ObserverSwarm.m); 3. schedule creation;
// 4. activation of 2. and 3.; 5. go

  observerSwarm =  [ObserverSwarm create: globalZone];
  SET_WINDOW_GEOMETRY_RECORD_NAME (observerSwarm);

  [observerSwarm buildObjects];
  [observerSwarm buildActions];
  [observerSwarm activateIn: nil];
  
  [observerSwarm go];

  return 0;

}
